# YasirPediaApi-Py
[![Repo Size](https://img.shields.io/github/repo-size/yasirarism/YasirPediaApi-py?style=flat-square)](https://github.com/yasirarism/YasirPediaApi-py)  [![Languages](https://img.shields.io/github/languages/top/yasirarism/YasirPediaApi-py?style=flat-square)](https://github.com/yasirarism/YasirPediaApi-py)  [![CodeFactor](https://www.codefactor.io/repository/github/yasirarism/YasirPediaApi-py/badge)](https://www.codefactor.io/repository/github/yasirarism/YasirPediaApi-py)

_Official Python Wrapper for YasirPedia API._

## How to install:
```
pip install yasirpedia-api
```

## Update to latest:

```
pip install -U yasirpedia-api
```

## Features From API:
1. Google Search (google)
2. TextPro (textpro)
3. KBBI (kbbi)
4. Layarkaca21 Scraper (lk21)
5. Terbit21 Scraper (terbit21)
6. IMDB Search (imdb_search)
7. Facebook Downloader (fbdl)


## Examples:
_For examples go to [examples dir](https://github.com/yasirarism/YasirPediaApi-py/blob/main/examples)._

## Copyright:
**Copyright 2022 by [YasirArisM](https://t.me/YasirArisM).**
